Documentation
¶
Index ¶
- func CreateCommand() *createCommand
- func CreateFile() (*os.File, error)
- func Decrypt(ciphertext []byte, password string) ([]byte, error)
- func DeleteCommand() *deleteCommand
- func DeleteFile() error
- func Encrypt(data []byte, password string) ([]byte, error)
- func GetSHA1(s *string) string
- func IsByteJSON(s []byte) bool
- func IsJSON(s *string) bool
- func IsJSONArray(s *string) bool
- func ReadFile() ([]byte, error)
- func RetrieveCommand() *retrieveCommand
- func WriteFile(f *os.File, d []byte) error
- type AWSSecrets
- type Command
- type CommandType
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateCommand ¶
func CreateCommand() *createCommand
func CreateFile ¶
func DeleteCommand ¶
func DeleteCommand() *deleteCommand
func DeleteFile ¶
func DeleteFile() error
func IsByteJSON ¶
func IsJSONArray ¶
func RetrieveCommand ¶
func RetrieveCommand() *retrieveCommand
RetrieveCommand
Check if record exists for $(pwd) and returns encrypted string if password is valid. If no record exists returns error.
Usage:
command [OPTIONS]
Options:
-p <password> Password that was used for creating record. required.
Examples:
refresh -p 123456
Types ¶
type AWSSecrets ¶
type AWSSecrets struct {
Data map[string]secretNormalized
}
func RetreiveSecrets ¶
func RetreiveSecrets(args []*string, pm bool, sc bool) (*AWSSecrets, error)
func (*AWSSecrets) Values ¶
func (s *AWSSecrets) Values() *string
type CommandType ¶
type CommandType string
1. Input a set of strings that identify names 2. flag for secrets manager 3. flag for parameter store 4. create command - create and exports vars for the current dir aka project and saves them locally encrypted 5. delete command - deletets secrets from current dir and unset them 6. apply check if secrets are created for the current dir and apply them if yes 7. refresh compares and writes secrets for the current dir 8. bind to tmux to set the keys for current dir 9. get secrets from the lambda function 10. get secrets from the ecs task def
const ( CreateType CommandType = "create" DeleteType CommandType = "delete" RetrieveType CommandType = "retrieve" RefreshType CommandType = "refresh" )